use crate::{auth::Backend, page, AppState};
use axum::{routing::get, Router};
use axum_login::login_required;
use maud::{html, Markup};
use tower_sessions::Session;

pub(crate) mod route;
pub(crate) mod station;
pub(crate) mod team;

async fn index(session: Session) -> Markup {
    let content = html! {
        h1 { (t!("app_name")) }
        a href="/auth/logout" {
            "Ausloggen"
        }
        nav {
            ul {
                li {
                    a role="button" href="/admin/station" {
                        (t!("stations"))
                    }
                }
                li {
                    a role="button" href="/admin/route" {
                        (t!("routes"))
                    }
                }
                li {
                    a role="button" href="/admin/team" {
                        (t!("teams"))
                    }
                }
        }
        }
    };
    page(content, session, false).await
}

pub(super) fn routes() -> Router<AppState> {
    Router::new()
        .route("/", get(index))
        .nest("/station", station::routes())
        .nest("/route", route::routes())
        .nest("/team", team::routes())
        .layer(login_required!(Backend, login_url = "/auth/login"))
}
